#ifndef NT2_INCLUDE_FUNCTIONS_RROR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RROR_HPP_INCLUDED

#include <nt2/bitwise/include/functions/rror.hpp>

#endif
